@@ -41,7 +41,16 @@ DOCUMENTATION__create_account = SwaggerDocumentation(
         name="Create account",
         description="Will create an account, if you have privileges to do so",
         body=[
-            ARG_RES__username
+            ARG_RES__username,
+            set_nullable(ARG_RES__password, "Whether the user is given a password"),
+            SwaggerArgumentResponse(
+                name=KEY__attach_as,
+                description="Whether the user will attach as a role",
+                arg_type=str,
+                required=False,
+                condition="Defaults to false",
+                example="my-role"
+            )
         ]
     )
 )
